<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="fr">
<context>
    <name>TaskbarFactory</name>
    <message>
        <location filename="../taskbarfactory.cpp" line="28"/>
        <source>Taskbar Plugin</source>
        <translation>Greffon barre des tâches</translation>
    </message>
    <message>
        <location filename="../taskbarfactory.cpp" line="49"/>
        <source>About Taskbar Plugin</source>
        <translation>À propos du greffon barre des tâches</translation>
    </message>
    <message>
        <location filename="../taskbarfactory.cpp" line="50"/>
        <source>Qmmp Taskbar Plugin</source>
        <translation>Greffon barre des tâches pour Qmmp</translation>
    </message>
    <message>
        <location filename="../taskbarfactory.cpp" line="51"/>
        <source>This plugin adds support for progress indicator in the Windows taskbar</source>
        <translation>Ce greffon ajoute la visualisation du progrès de la lecture dans la barre des tâches de Windows</translation>
    </message>
    <message>
        <location filename="../taskbarfactory.cpp" line="52"/>
        <source>Written by: Ilya Kotov &lt;forkotov02@ya.ru&gt;</source>
        <translation>Écrit par : Ilya Kotov &lt;forkotov02@ya.ru&gt;</translation>
    </message>
</context>
</TS>
